Change last parameter of umoven() from char* to void*

Saves tons of casts.

Signed-off-by: Denys Vlasenko <dvlasenk@redhat.com>
diff --git a/util.c b/util.c
index 02c5b9a..fd9053a 100644
--- a/util.c
+++ b/util.c
@@ -835,7 +835,7 @@
 		fprintf(stderr, "Out of memory\n");
 		return;
 	}
-	if (umoven(tcp, addr, size, (char *) iov) >= 0) {
+	if (umoven(tcp, addr, size, iov) >= 0) {
 		for (i = 0; i < len; i++) {
 			/* include the buffer number to make it easy to
 			 * match up the trace with the source */
@@ -881,7 +881,7 @@
 		strsize = len + 16;
 	}
 
-	if (umoven(tcp, addr, len, (char *) str) < 0)
+	if (umoven(tcp, addr, len, str) < 0)
 		return;
 
 	/* Space-pad to 16 bytes */
@@ -966,11 +966,12 @@
 #define PAGMASK	(~(PAGSIZ - 1))
 /*
  * move `len' bytes of data from process `pid'
  * at address `addr' to our space at `laddr'
  */
 int
-umoven(struct tcb *tcp, long addr, unsigned int len, char *laddr)
+umoven(struct tcb *tcp, long addr, unsigned int len, void *our_addr)
 {
+	char *laddr = our_addr;
 	int pid = tcp->pid;
 	unsigned int n, m, nread;
 	union {
@@ -966,11 +966,12 @@
 /*
  * move `len' bytes of data from process `pid'
- * at address `addr' to our space at `laddr'
+ * at address `addr' to our space at `our_addr'
  */
 int